/**
 ** @author: Ben Y. Zhao (ravenben@cs.berkeley.edu)
 ** @version: CVS Version: $Revision: 1.3 $  Date: $Date: 1999/11/05 09:45:35 $
 ** (c) 2000 by Ben Yanbin Zhao and the Regents of the University of California
 **/

package ninja.xset;

import java.io.*;
import java.util.*;

/********************
 ** Class LogEntry **
 ********************
 ** Class that encapsulates the data pertaining to a given log entry.
 ** It offers methods to generate string log entries, as well as 
 ** methods to parse those string entries back into objects.
 **/

public class LogEntry {

  //public fields
  //Constants for log Types
  public static final int LOGTYPEINSERT = 0;
  public static final int LOGTYPEDELETE = 1;
  public static final int LOGTYPECHECKPOINT = 2;
  //Constants noting begin and end log types
  public static final int LOGBEGIN = 0;
  public static final int LOGEND = 1;
 
  //private fields
  int logType;
  int beginEnd;
  long sequenceID;
  long timestamp = 0;
  String stringEntry;

  public LogEntry (String stringLogEntry) throws RecoveryException {
    StringTokenizer st = new StringTokenizer(stringLogEntry, "_");
    if (st.hasMoreTokens()) logType = Integer.parseInt(st.nextToken());
    if (st.hasMoreTokens()) sequenceID = Long.parseLong(st.nextToken());
    if (st.hasMoreTokens()) beginEnd = Integer.parseInt(st.nextToken());
    if (st.hasMoreTokens()) timestamp = Long.parseLong(st.nextToken());
    if (timestamp == 0) 
      throw new RecoveryException("Error parsing log entry!");
    stringEntry = stringLogEntry;
  }

  public LogEntry (int lType, long seqID, int bEnd) {
    logType = lType;
    beginEnd = bEnd;
    sequenceID = seqID;
    timestamp = System.currentTimeMillis();

    StringBuffer sb = new StringBuffer(String.valueOf(logType));
    sb.append('_');
    sb.append(sequenceID);
    sb.append('_');
    sb.append(beginEnd);
    sb.append('_');
    sb.append(System.currentTimeMillis());
    sb.append('\n');
    stringEntry = sb.toString();  
  }

  public int getLogType() {
    return logType;
  }

  public int getBeginEnd() {
    return beginEnd;
  }

  public long getSequenceID() {
    return sequenceID;
  }

  public long getTimestamp() {
    return timestamp;
  }

  public String toString() {
    return stringEntry;
  }

}
