/**
 * @author: Ben Y. Zhao (ravenben@cs.berkeley.edu)
 ** @version: CVS Version: $Revision: 1.5 $  Date: $Date: 2000/01/06 21:19:18 $
 ** (c) 2000 by Ben Yanbin Zhao and the Regents of the University of California
 **/

package ninja.xset;

import java.io.*;
import java.util.*;
import java.rmi.*;
//import ninja.ispace.*;
//import ninja.xset.XSetServiceIF;

/**
 ** A sample client class for the XSet project
 **/
public class XSetQueryClient {
    // iSpaceLoaderIF loader;
  XSetServiceIF XSetService;
  String hostname = null;
  String path = null;
  final String query = "<?xml version=\"1.0\"?><PRINTCAP><COLOR>YES</COLOR></PRINTCAP>";

  /**
   ** simple constructor that initializes two fields according to 
   ** cmdline arguments
   **/
  public XSetQueryClient(String host, String xmlpath) {
    hostname = host;
    path = xmlpath;
  }

  /**
   ** Main code is here
   ** The code simply calls XSet to index the files in the XML path,
   ** and then does a query on them with a hard-coded XML query fragment.
   **/
  public void run() {
    String [] servlist;
    Vector results;
    boolean simplequery = false;
    boolean enumeratetags = false;
    boolean querytags = false;

    try {
	XSetService = (XSetServiceIF) Naming.lookup("rmi:///XSet");
      if (XSetService == null) throw new XSetException("UTOH");

      XSetService.AddFiles(path);

      if (simplequery) {
	results = XSetService.Query(query);
	System.out.println("Result: "+results.toString());
      }

      if (querytags) {
	Vector v = new Vector();
	v.addElement("NAME");
	results = XSetService.Query(query, v);
	if (results.size() == 0) System.out.println("No Matches.");
	else {
	  System.out.println("Matches:");
	  Hashtable ht = (Hashtable) results.elementAt(0);
	  String out = (String) ((Vector) ht.get("NAME")).toString();
	  System.out.println("Match: "+out);
	}
      } 

      if (enumeratetags) {
	Vector v = new Vector();
	String [] tagPath = new String [2];
	tagPath[0] = "PRINTCAP";
	tagPath[1] = "ROOM";
	v = XSetService.EnumerateTag(tagPath);
	System.out.println("Enumeration for room: "+v.toString());
      }

      XSetService.Checkpoint();
/*      XSetService.ClearAll();
      results = XSetService.Query(query);
      if (results == null) System.out.println("No Matches.");
      else System.out.println("Matches: "+results.toString());
*/
    } catch (Exception e) {
      System.out.println("Exception while execution: "+e);
      e.printStackTrace();
    }
  }
  
  public static void main(String argv[]) {
    if (argv.length != 2) {
      System.out.println("Wrong # of arguments!");
      System.out.println("  java ninja.xset.XSetQueryClient hostname pathtoxmlfiles");
      System.out.println("e.g.: java ninja.xset.XSetQueryClient joker.cs.berkeley.edu /usr/local/xmlrepository/");
      return;
    }
    XSetQueryClient xs = new XSetQueryClient(argv[0], argv[1]);
    xs.run();
  }
}
